# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .activities_summary import ActivitiesSummary
from .address import Address
from .amount import Amount
from .authorization_url import AuthorizationUrl
from .bulk_element import BulkElement
from .citation import Citation
from .contributor import Contributor
from .contributor_attributes import ContributorAttributes
from .contributor_email import ContributorEmail
from .contributor_orcid import ContributorOrcid
from .country import Country
from .created_date import CreatedDate
from .credit_name import CreditName
from .day import Day
from .disambiguated_organization import DisambiguatedOrganization
from .education import Education
from .education_summary import EducationSummary
from .educations import Educations
from .employment import Employment
from .employment_summary import EmploymentSummary
from .employments import Employments
from .external_id import ExternalID
from .external_i_ds import ExternalIDs
from .funding import Funding
from .funding_contributor import FundingContributor
from .funding_contributor_attributes import FundingContributorAttributes
from .funding_contributors import FundingContributors
from .funding_group import FundingGroup
from .funding_summary import FundingSummary
from .funding_title import FundingTitle
from .fundings import Fundings
from .fuzzy_date import FuzzyDate
from .group_id_record import GroupIdRecord
from .group_id_records import GroupIdRecords
from .item import Item
from .items import Items
from .keyword import Keyword
from .last_modified_date import LastModifiedDate
from .month import Month
from .notification import Notification
from .notification_permission import NotificationPermission
from .organization import Organization
from .organization_address import OrganizationAddress
from .organization_defined_funding_sub_type import OrganizationDefinedFundingSubType
from .other_name import OtherName
from .peer_review import PeerReview
from .peer_review_group import PeerReviewGroup
from .peer_review_summary import PeerReviewSummary
from .peer_reviews import PeerReviews
from .person_external_identifier import PersonExternalIdentifier
from .publication_date import PublicationDate
from .researcher_url import ResearcherUrl
from .source import Source
from .source_client_id import SourceClientId
from .source_name import SourceName
from .source_orcid import SourceOrcid
from .subtitle import Subtitle
from .title import Title
from .translated_title import TranslatedTitle
from .url import Url
from .work import Work
from .work_bulk import WorkBulk
from .work_contributors import WorkContributors
from .work_group import WorkGroup
from .work_summary import WorkSummary
from .work_title import WorkTitle
from .works import Works
from .year import Year
